/*************************************************
*     rpld - an IBM style RIPL server            *
*************************************************/

/* Copyright (c) 1999, James McKenzie.
 *                      All rights reserved
 * Copyright (c) 1998, Christopher Lightfoot.
 *                      All rights reserved
 *
 * By using this file, you agree to the terms and conditions set
 * forth in the LICENCE file which can be found at the top level of
 * the rpld distribution.
 *
 * IBM is a trademark of IBM corp.
 *
 */

/*
 *  Lexer for RPLD conf files
 *
 *  $Log: rpld_conf.lex,v $
 *  Revision 1.4  1999/09/26 10:46:56  root
 *  #
 *
 *  Revision 1.3  1999/09/13 11:17:35  root
 *  \#
 *
 *  Revision 1.2  1999/09/13 11:08:34  root
 *  \#
 *
 *  Revision 1.1  1999/09/13 11:04:13  root
 *  \#
 *
 *  
 */

%x	COMMENT

%{
static char rcsid[]="$Id: rpld_conf.lex,v 1.4 1999/09/26 10:46:56 root Exp root $";

#include <stdio.h>
#include <string.h>
#include <stdlib.h>
#include "rpld_conf.tab.h"


// line number
int lineno = 1;

// function to convert hex digits to a MAC address
void strtomac(char *s, char *mac);

void strtomac(char *s, char *mac)
{
	// mac address *must* be in form 00:11:22:33:44:55
	int i;

	for (i = 0; i < 6; i++) *(mac + i) = (unsigned char)strtol(s + i * 3, NULL, 16);
}


%}
ws	[ \t]+
nl	\n
hb	[0-9A-Fa-f][0-9A-Fa-f]

%%

{ws}			;
{nl}			{ lineno++; }

\/\/.*			;

"/*"			BEGIN COMMENT;
<COMMENT>.	|
<COMMENT>\n		;
<COMMENT>"*/"		BEGIN INITIAL;

[{]			{ return BLOCK_START; }

[}]			{ return BLOCK_END; }

{hb}:{hb}:{hb}:{hb}:{hb}:{hb}	{
				strtomac(yytext, (yylval.mac_address));
				return MACADDR;
			}

{hb}:{hb}:{hb}:{hb}:{hb}:{hb}/[1-6]	{
				strtomac(yytext, (yylval.pm.mac_address));
				yylval.pm.mac_len = yytext[13] - '0';
				return MACADDR_PARTIAL;
			}

0x[0-9A-Fa-f]+ {
				yylval.number = strtol(yytext + 2, NULL, 16);
				return NUMBER;
			}

[0-9]+			{
				int i; i = strtol(yytext, NULL, 10);
				yylval.number = i; return NUMBER;
			}

[A-Za-z\-_]+		{ yylval.name = strdup(yytext); return NAME; }

\"[A-Za-z0-9.:/\-_ ]*\"	{ yylval.text = strdup(yytext + 1); *(yylval.text + strlen(yylval.text) - 1) = 0; return TEXT;}

.			{ return yytext[0]; }

%%


int yywrap()
{
	return 1;
}

